@@ -5,18 +5,16 @@
 # Standard Library
 # https://docs.python.org/3/library/functools.html?highlight=functools#functools.cached_property
 from functools import cached_property
-from os import chdir, getenv, access, X_OK
-import re
+from os import X_OK, access, chdir, getenv
 from pathlib import Path
+import re
+from shutil import which
 from subprocess import run
 from sys import exit as sys_exit
-from typing import Union, List
-from shutil import which
+from typing import List, Union
 
-# PyPi
 from pydymenu import fzf
 
-# Project Modules
 from mydot.console import console
 from mydot.exceptions import MissingRepositoryLocation, WorktreeMissing
 from mydot.system_funcs import script_plus_args
@@ -86,6 +84,7 @@ class Dotfiles:
         console.print("\nModified Files:", style="header")
         run(self._git_base + ["status", "-s"])
 
+    # ACTIONS
     def edit_files(self) -> List[str]:
         """Interactively choose dotfiles to open in text editor."""
         edits = fzf(
@@ -104,6 +103,34 @@ class Dotfiles:
             self.freshen()
             return edits
 
+    def grep(self, regex: str) -> List[str]:
+        """Interactively choose dotfiles to open in text editor."""
+        # LATER make it work for multiple regex searches
+        proc = run(
+            ["grep", "-I", "-l", regex] + self.list_all,
+            capture_output=True,
+            text=True,
+        )
+        hits = [h for h in proc.stdout.split("\n") if len(h) > 0]
+        if len(hits) == 0:
+            sys_exit("No matches for your regex search found in tracked dotfiles.")
+        choices = fzf(
+            hits,
+            prompt="Choose files to open: ",
+            multi=True,
+            preview=f"grep {regex} -n --context=3 --color=always" + " {}",
+        )
+        # TODO: abstract these functions into an Opener(ABC/Protocol)
+        if choices is not None:
+            if len(choices) == 1:
+                run([self.editor, "-c", f"/{regex}", choices[0]])
+            else:
+                run([self.editor, "-o", "-c", f"/{regex}"] + choices)
+            self.freshen()
+            return choices
+        else:
+            sys_exit("No selections made. Cancelling action.")
+
     def run_executable(self) -> str:
         """Interactively choose an executable to run. Optionally add arguements."""
         exe = fzf(
@@ -159,8 +186,10 @@ class Dotfiles:
             self.show_status()
             sys_exit("\nNo staged changes to restore.")
 
+    # PROPERTIES
     @cached_property
     def short_status(self) -> List[str]:
+        """List of lines in git status porecelain=v1 format (except renames)."""
         output = run(
             self._git_base
             + ["status", "--short", "--untracked-files=no", "--porcelain", "-z"],
